function[Pal]=Gen_Pal(Pal_Str,V_min,V_max,C_min,C_max,Nb_Col)
// Generate a color colormap
// Can generate a colormap or a 'colorsubmap', i.e. a part of a colormap
// according to a color range (C_min, C_max) and a value range
// (V_min, V_max)
//
// For example if we want to be able to compair to sets of results
// with theoretical values in [0,1] but with avalue range
// in [0.5 1] for the first one and  [0.3,1] for the last one,
// we use GenPal(Jet, 0.5, 1, 0, 1, 64) for the firstr one and
//        GenPal(Jet, 0.3, 1, 0, 1, 64) for the last one.
//
// Pal_str : colormap name, in Jet, Jet2, Cool, Gray1, Gray3, Scilab
// Nb_Col  : number of colors in the colormap
if Pal_Str == 'Jet' then
  V_min = maxi(V_min, C_min);
  V_max = mini(V_max, C_max);
  for i = 1:Nb_Col;
    iC = V_min + (i - 1) / (Nb_Col-1) * (V_max-V_min) ;
    iC =  (iC - C_min)/(C_max - C_min) * 64;
    Pal(i,1) = Jet_Red(iC) ;
    Pal(i,2) = Jet_Green(iC) ;
    Pal(i,3) = Jet_Blue(iC) ;
  end
elseif Pal_Str == 'Jet2' then
  V_min = maxi(V_min, C_min);
  V_max = mini(V_max, C_max);
  VT_min = 1-V_max
  VT_max = 1-V_min
  for i = 1:Nb_Col;
    iC = VT_min + (i - 1) / (Nb_Col-1) * (VT_max-VT_min) ;
    iC =  (iC - C_min)/(C_max - C_min) * 64;
    Pal_T(i,1) = Jet_Red(iC) ;
    Pal_T(i,2) = Jet_Green(iC) ;
    Pal_T(i,3) = Jet_Blue(iC) ;
  end
  for i = 1:Nb_Col;
    Pal(i,1:3) = Pal_T(Nb_Col-i+1,1:3);
  end ;
elseif Pal_Str == 'Cool' then
  V_min = maxi(V_min, C_min);
  V_max = mini(V_max, C_max);
  for i = 1:Nb_Col;
    Pal(i,3) = 1;
    iC = V_min + (i - 1) / (Nb_Col-1) * (V_max-V_min);
    Pal(i,1) =  (iC - C_min)/(C_max - C_min);
    Pal(i,2) = 1-Pal(i,1);
  end ;
elseif Pal_Str == 'Gray1' then
  V_min = maxi(V_min, C_min);
  V_max = mini(V_max, C_max);
  for i = 1:Nb_Col;
   iC = V_min + (i - 1) / (Nb_Col-1) * (V_max-V_min);
   iC =  (iC - C_min)/(C_max - C_min);
    Pal(i,1) = 1-(1-iC);
    Pal(i,2) = 1-(1-iC);
    Pal(i,3) = 1-(1-iC);
  end ;
elseif Pal_Str == 'Gray3' then
  V_min = maxi(V_min, C_min);
  V_max = mini(V_max, C_max);
  for i = 1:Nb_Col;
   iC = V_min + (i - 1) / (Nb_Col-1) * (V_max-V_min) ;
   iC =  (iC - C_min)/(C_max - C_min);
    Pal(i,1) = 1-(1-iC)**3;
    Pal(i,2) = 1-(1-iC)**3;
    Pal(i,3) = 1-(1-iC)**3;
  end ;
elseif Pal_Str == 'Scilab' then
  unit = file ('open',FEM_Func_Path+'Scilab.pal','old')
  Pal = read(unit,-1,3)
  file('close',unit)
end




